transfocate
===========
.. image:: https://travis-ci.org/pcdshub/transfocate.svg?branch=master
    :target: https://travis-ci.org/pcdshub/transfocate

.. image:: https://codecov.io/gh/pcdshub/transfocate/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/pcdshub/transfocate

Authors : Teddy Rendahl, Taryn Imamura 

Automated calculation of beryllium lens focusing optics for MFX Transfocator
